import { AzureFunction, Context, HttpRequest } from "@azure/functions";
import "reflect-metadata";
import { AuthService, FunctionResponse } from "./Interfaces";
export declare class AzureFunctionsController {
    authService?: AuthService;
    /**
     * @param authService The AuthService to use with the '@CheckAuth' decorater
     */
    constructor(authService?: AuthService);
    /**
     * Custom setup method that is ran first before validation.
     *
     * @param context AzureFunction context object
     * @param req HTTPRequest object
     * @returns An error FunctionResponse or null if no error
    */
    preValidation(context: Context, req: HttpRequest): Promise<FunctionResponse<unknown> | null>;
    /**
     * Custom validation method that is ran before the GET/POST/PATCH logic
     *
     * @param context AzureFunction context object
     * @param req HTTPRequest object
     * @returns An error FunctionResponse or null if no error
     */
    validation(context: Context, req: HttpRequest): Promise<FunctionResponse<unknown> | null>;
    /**
     * Custom setup method that is ran after validation but before the GET/POST/PATCH logic
     *
     * @param context AzureFunction context object
     * @param req HTTPRequest object
     * @returns An error FunctionResponse or null if no error
    */
    postValidation(context: Context, req: HttpRequest): Promise<FunctionResponse<unknown> | null>;
    /**
     * Builds the Azure Function call this and export the returned function.
     *
     * @returns An AzureFunction
     */
    build(): AzureFunction;
}
